@@ -1,10 +1,9 @@
 print.CopyDetect<- function(x, ...){
 
 	cat("************************************************************************","\n")
-	cat("CopyDetect -- An R Package to Compute Statistical Indices for Detecting","\n")
-	cat("             ","Answer Copying on Multiple-Choice Tests","\n")
+	cat("CopyDetect - An R Package to Compute Response Similarity Indices for Multiple-Choice Tests","\n")
 	cat("","\n")
-	cat("Version 1.2  2016","\n")
+	cat("Version 1.3, released on October 2018","\n")
 	cat("","\n")
 	cat("Cengiz Zopluoglu","\n")
 	cat("","\n")
@@ -17,22 +16,22 @@ print.CopyDetect<- function(x, ...){
 	cat("","\n")
 	cat("Processing Date: ",date(),"\n")
 	cat("","\n")
-	cat("   Suspected Copier: Examinee",x$suspected.pair[1],"\n")
-	cat("      Response Vector:",sprintf(rep("%1.0f",ncol(x$data)),x$data[x$suspected.pair[1],]),"\n")
+	cat("   Suspected Copier: Examinee ID",x$single.pair[1],"\n")
+	cat("      Response Vector:",sprintf(rep("%1.0f",ncol(x$data[,x$item.loc])),x$data[,x$item.loc][x$single.pair2[1],]),"\n")
 	cat("","\n")
-	cat("   Suspected Source: Examinee",x$suspected.pair[2],"\n")
-	cat("      Response Vector:",sprintf(rep("%1.0f",ncol(x$data)),x$data[x$suspected.pair[2],]),"\n")
+	cat("   Suspected Source: Examinee ID",x$single.pair[2],"\n")
+	cat("      Response Vector:",sprintf(rep("%1.0f",ncol(x$data[,x$item.loc])),x$data[,x$item.loc][x$single.pair2[2],]),"\n")
 	cat("","\n")
-	cat("   Number-Correct Score for Examinee",x$suspected.pair[1],":",rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),"\n")
-	cat("   Number-Correct Score for Examinee",x$suspected.pair[2],":",rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"\n")
+	cat("   Number-Correct Score for Examinee ID",x$single.pair[1],":",rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),"\n")
+	cat("   Number-Correct Score for Examinee ID",x$single.pair[2],":",rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"\n")
 	cat("","\n")
-	cat("   MLE Ability Estimate for Examinee",x$suspected.pair[1],":",round(x$W.index$ability1,4),"\n")
-	cat("   MLE Ability Estimate for Examinee",x$suspected.pair[2],":",round(x$GBT.index$ability2,4),"\n")
+	cat("   MLE Ability Estimate for Examinee ID",x$single.pair[1],":",round(x$thetas[x$single.pair2[1]],4),"\n")
+	cat("   MLE Ability Estimate for Examinee ID",x$single.pair[2],":",round(x$thetas[x$single.pair2[2]],4),"\n")
 	cat("","\n")
 	cat("   Number of Identical Incorrect Responses:",sprintf("%1.0f",
-                         length(which(x$data[x$suspected.pair[1],]== 0 & x$data[x$suspected.pair[2],]==0))+
-                         length(which(is.na(x$data[x$suspected.pair[1],])==TRUE & is.na(x$data[x$suspected.pair[2],])==TRUE))),"\n")
-	cat("   Number of Identical Correct Responses:",sprintf("%1.0f",length(which(x$data[x$suspected.pair[1],]== 1 & x$data[x$suspected.pair[2],]==1))),"\n")
+                         length(which(x$data[,x$item.loc][x$single.pair2[1],]== 0 & x$data[,x$item.loc][x$single.pair2[2],]==0))+
+                         length(which(is.na(x$data[,x$item.loc][x$single.pair2[1],])==TRUE & is.na(x$data[,x$item.loc][x$single.pair2[2],])==TRUE))),"\n")
+	cat("   Number of Identical Correct Responses:",sprintf("%1.0f",length(which(x$data[,x$item.loc][x$single.pair2[1],]== 1 & x$data[,x$item.loc][x$single.pair2[2],]==1))),"\n")
 	cat("   Number of Identical Responses:",sprintf("%1.0f",x$W.index$obs.match),"\n")
 	cat("","\n")
 	cat("","\n")
@@ -44,6 +43,13 @@ print.CopyDetect<- function(x, ...){
 		if(x$W.index$p.value<.001){ w001 <- "Flagged"} else w001 <- "Not Flagged"
 	} else { w05 <- "NA"; w01 <- "NA"; w001 <- "NA"}
 
+	if(is.na(x$M4.index$p.value)!=TRUE){
+
+		if(x$M4.index$p.value<.05){  m05  <- "Flagged"} else m05  <- "Not Flagged"
+		if(x$M4.index$p.value<.01){  m01  <- "Flagged"} else m01  <- "Not Flagged"
+		if(x$M4.index$p.value<.001){ m001 <- "Flagged"} else m001 <- "Not Flagged"
+	} else { m05 <- "NA"; m01 <- "NA"; m001 <- "NA"}
+
 
 	if(is.na(x$GBT.index$p.value)!=TRUE){
 
@@ -117,6 +123,11 @@ print.CopyDetect<- function(x, ...){
 	    sprintf("%15s",w01),
 	    sprintf("%15s",w001),"\n")	
 
+	cat(sprintf("%18s","M4"),
+	    sprintf("%14s",m05),
+	    sprintf("%15s",m01),
+	    sprintf("%15s",m001),"\n")
+
 	cat(sprintf("%18s","GBT"),
 	    sprintf("%14s",gbt05),
 	    sprintf("%15s",gbt01),
@@ -153,8 +164,8 @@ print.CopyDetect<- function(x, ...){
       cat("","\n")
 	cat("   Estimated Probabilities of Correct Response:","\n")
 	cat("","\n")
-      cat("                     Examinee",x$suspected.pair[1],"    Examinee",x$suspected.pair[2],"\n")
-	for(i in 1:ncol(x$data)) { cat(sprintf("%15s",paste("Item",i)),
+      cat("                     Examinee",x$single.pair2[1],"    Examinee",x$single.pair2[2],"\n")
+	for(i in 1:ncol(x$data[,x$item.loc])) { cat(sprintf("%15s",paste("Item",i)),
 						 sprintf("%12.3f",x$GBT.index$prob.cor[i,1]),
 						 sprintf("%15.3f",x$GBT.index$prob.cor[i,2]),
  				             "\n") 
@@ -175,14 +186,14 @@ print.CopyDetect<- function(x, ...){
 	cat("   Probability of Matching on Each Item:","\n")
 	cat("","\n")
 	cat("                    Prob. of Matching","\n")
-	for(i in 1:ncol(x$data)) { cat(sprintf("%15s",paste("Item",i)),
+	for(i in 1:ncol(x$data[,x$item.loc])) { cat(sprintf("%15s",paste("Item",i)),
 						 sprintf("%12.3f",x$GBT$prob.match[i]),
  				             "\n") 
                                 }
 	cat("","\n")
 	cat("   Exact Probability Distribution for Number of Matches:","\n")
 	cat("","\n")
-	for(i in 1:(ncol(x$data)+1)) { cat(sprintf("%30s",paste("Probability of ",i-1," Match",sep="")),
+	for(i in 1:(ncol(x$data[,x$item.loc])+1)) { cat(sprintf("%30s",paste("Probability of ",i-1," Match",sep="")),
 						 sprintf("%12.3f",
                                      as.numeric(as.matrix(x$GBT$exact.prob.dist)[i,2])),
  				             "\n") 
@@ -195,14 +206,14 @@ print.CopyDetect<- function(x, ...){
 	cat("***************************","          K Index          ","*******************************","\n")
 	cat("","\n")
  if(is.null(x$K.index)!=TRUE) {
-	cat("   Number-Incorrect Score for Examinee",x$suspected.pair[1],"(suspected copier):",
-      ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),"\n")
+	cat("   Number-Incorrect Score for Examinee",x$single.pair2[1],"(suspected copier):",
+      ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),"\n")
 	cat("","\n")
-	cat("   Number-Incorrect Score for Examinee",x$suspected.pair[2],"(suspected source):",
-              ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"\n")
+	cat("   Number-Incorrect Score for Examinee",x$single.pair2[2],"(suspected source):",
+              ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"\n")
 	cat("","\n")
       cat("   Number of Examinees in the Subgroup of","\n") 
-	cat("   Number-Incorrect Score",ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),":",
+	cat("   Number-Incorrect Score",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),":",
          length(x$K.index$subgroups)
          ,"\n")
 	cat("","\n")
@@ -238,13 +249,13 @@ print.CopyDetect<- function(x, ...){
 	  cat("   with Source Examinee for This Number-Incorrect Subgroup:","\n") 
 	  cat("","\n")
 	  cat("      ",round(mean(x$K.index$emp.agg,na.rm=TRUE),4),
-          "/",ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"=",
+          "/",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"=",
 	    round(round(mean(x$K.index$emp.agg,na.rm=TRUE),4)/
-	    (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE)),4),"\n")
+	    (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE)),4),"\n")
 	  cat("","\n")
 	  cat("   Probability of Observing",
-			 length(which(x$data[x$suspected.pair[1],]== 0 & x$data[x$suspected.pair[2],]==0))+
-                   length(which(is.na(x$data[x$suspected.pair[1],])==TRUE & is.na(x$data[x$suspected.pair[2],])==TRUE)),
+			 length(which(x$data[,x$item.loc][x$single.pair2[1],]== 0 & x$data[,x$item.loc][x$single.pair2[2],]==0))+
+                   length(which(is.na(x$data[,x$item.loc][x$single.pair2[1],])==TRUE & is.na(x$data[,x$item.loc][x$single.pair2[2],])==TRUE)),
             "or More Identical Incorrect","\n") 
 	  cat("   Matches Using Binomial Distribution =",round(x$K.index$k.index,4),"\n") 
 	  cat("","\n")
@@ -282,7 +293,7 @@ print.CopyDetect<- function(x, ...){
                    sprintf("%8s","Model"),
                    sprintf("%10s","Model"),"\n")
 	cat("","\n")
-	for(i in 1:(ncol(x$data)+1)) { 
+	for(i in 1:(ncol(x$data[,x$item.loc])+1)) { 
 			
 		cat(sprintf("%7.0f",i-1),
                 sprintf("%13.0f",length(x$K.variants$subgroups[[i]])),
@@ -292,76 +303,76 @@ print.CopyDetect<- function(x, ...){
                 sprintf("%10.3f",x$K.variants$pred3[i]),"\n")
 	}
 	cat("","\n")
-	cat("   Number-Incorrect Score for Examinee",x$suspected.pair[1],":",ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),"\n")
+	cat("   Number-Incorrect Score for Examinee",x$single.pair2[1],":",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),"\n")
 	cat("","\n")
-	cat("   Number-Incorrect Score for Examinee",x$suspected.pair[2],":",ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"\n")
+	cat("   Number-Incorrect Score for Examinee",x$single.pair2[2],":",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"\n")
 	cat("","\n")
 	cat("   Binomial Probability of Matching on an Identical Incorrect Response","\n") 
-	cat("   with Source Examinee for Number-Incorrect Subgroup",ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),":","\n") 
+	cat("   with Source Examinee for Number-Incorrect Subgroup",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),":","\n") 
       cat("","\n")
 
-	if(x$K.variants$pred1[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]<
-	   (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE)) &
-	   x$K.variants$pred1[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]>0
+	if(x$K.variants$pred1[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]<
+	   (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE)) &
+	   x$K.variants$pred1[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]>0
          ){
 
 	cat("              ","for K1 index:",
-                            round(x$K.variants$pred1[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)],3),
-				    "/",ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"=",
-				   round((x$K.variants$pred1[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)])/
-				   (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE)),3),"\n")
+                            round(x$K.variants$pred1[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)],3),
+				    "/",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"=",
+				   round((x$K.variants$pred1[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)])/
+				   (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE)),3),"\n")
 	} else 
-		if(x$K.variants$pred1[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]>
-	         (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE))){   
+		if(x$K.variants$pred1[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]>
+	         (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE))){   
                   cat("              ","for K1 index is set to .999, because predicted value was higher than 1","\n")
             } else
-		   if(x$K.variants$pred1[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]<=0){
+		   if(x$K.variants$pred1[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]<=0){
 	                   cat("              ","for K1 index is set to .001, because predicted value was smaller than 0","\n")
                }
 
 	cat("","\n")
 
-	if(x$K.variants$pred2[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]<
-	   (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE)) &
-	   x$K.variants$pred2[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]>0
+	if(x$K.variants$pred2[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]<
+	   (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE)) &
+	   x$K.variants$pred2[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]>0
          ){
 
 	    cat("              ","for K2 index:",
-                            round(x$K.variants$pred2[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)],3),
-				    "/",ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"=",
-				   round((x$K.variants$pred2[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)])/
-				   (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE)),3),"\n")
+                            round(x$K.variants$pred2[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)],3),
+				    "/",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"=",
+				   round((x$K.variants$pred2[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)])/
+				   (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE)),3),"\n")
 	  } else 
-		if(x$K.variants$pred2[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]>
-	         (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE))){   
+		if(x$K.variants$pred2[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]>
+	         (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE))){   
                   cat("              ","for K2 index is set to .999, because predicted value was higher than 1","\n")
             } else
-		   if(x$K.variants$pred2[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]<=0){
+		   if(x$K.variants$pred2[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]<=0){
 	                   cat("              ","for K2 index is set to .001, because predicted value was smaller than 0","\n")
                }
 
 	cat("","\n")
 
-	if(x$K.variants$pred3[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]<
-	   (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE))
+	if(x$K.variants$pred3[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]<
+	   (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE))
          ){
 
 	cat("   Predicted Average Number of Identical Incorrect Response","\n") 
-	cat("   with Source Examinee for Number-Incorrect Subgroup",ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),"\n")  
+	cat("   with Source Examinee for Number-Incorrect Subgroup",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),"\n")  
 	cat("   (parameter to be used for S1 index in Poisson Distribution):          ",
-      round(x$K.variants$pred3[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)],3),
+      round(x$K.variants$pred3[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)],3),
       "\n")
 	} else 
-		if(x$K.variants$pred3[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]>
-	         (ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE))){   
+		if(x$K.variants$pred3[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]>
+	         (ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE))){   
                   cat("   Predicted average number of identical incoccrect response is set to",
-                  ncol(x$data)-rowSums(x$data[x$suspected.pair[2],],na.rm=TRUE),"\n")
+                  ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[2],],na.rm=TRUE),"\n")
                   cat("   ,the maximum possible number of incorrect matches, for S1 index.","\n")
             }
 	cat("","\n")
 	cat("   Probability of Observing",
-			length(which(x$data[x$suspected.pair[1],]== 0 & x$data[x$suspected.pair[2],]==0))+
-                  length(which(is.na(x$data[x$suspected.pair[1],])==TRUE & is.na(x$data[x$suspected.pair[2],])==TRUE)),
+			length(which(x$data[,x$item.loc][x$single.pair2[1],]== 0 & x$data[,x$item.loc][x$single.pair2[2],]==0))+
+                  length(which(is.na(x$data[,x$item.loc][x$single.pair2[1],])==TRUE & is.na(x$data[,x$item.loc][x$single.pair2[2],])==TRUE)),
           "or More Identical Incorrect","\n") 
 	cat("   Matches Using Binomial Distribution","\n") 
 	cat("","\n")
@@ -370,8 +381,8 @@ print.CopyDetect<- function(x, ...){
 	cat("     ","--- K2 index p value:",round(x$K.variants$K2.index,3),"\n")
 	cat("","\n")
 	cat("   Probability of Observing",
-			length(which(x$data[x$suspected.pair[1],]== 0 & x$data[x$suspected.pair[2],]==0))+
-                  length(which(is.na(x$data[x$suspected.pair[1],])==TRUE & is.na(x$data[x$suspected.pair[2],])==TRUE)),
+			length(which(x$data[,x$item.loc][x$single.pair2[1],]== 0 & x$data[,x$item.loc][x$single.pair2[2],]==0))+
+                  length(which(is.na(x$data[,x$item.loc][x$single.pair2[1],])==TRUE & is.na(x$data[,x$item.loc][x$single.pair2[2],])==TRUE)),
           "or More Identical Incorrect","\n") 
 	cat("   Matches Using Poisson Distribution","\n") 
 	cat("","\n")
@@ -402,7 +413,7 @@ print.CopyDetect<- function(x, ...){
 	
 
 	cat("","\n")
-	for(i in 1:(ncol(x$data)+1)) { 
+	for(i in 1:(ncol(x$data[,x$item.loc])+1)) { 
 			
 		cat(sprintf("%7.0f",i-1),
                 sprintf("%13.0f",length(x$K.variants$subgroups[[i]])),
@@ -420,33 +431,40 @@ print.CopyDetect<- function(x, ...){
       cat(		 sprintf("%17s","Score Group"),
                    sprintf("%14s","Values"),"\n")
 	cat("","\n")
-	for(i in 1:(ncol(x$data)+1)) { 
+	for(i in 1:(ncol(x$data[,x$item.loc])+1)) { 
 			
 		cat(sprintf("%13.0f",i-1),
                 sprintf("%19.3f",x$K.variants$pred4[i]),
                 "\n")
 	}
 	cat("","\n")
-	if(x$K.variants$pred4[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]<
-	   ncol(x$data)
+	if(x$K.variants$pred4[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]<
+	   ncol(x$data[,x$item.loc])
          ){
 
 	cat("   Predicted Average Number of Identical Response","\n") 
-	cat("   with Source Examinee for Number-Incorrect Subgroup",ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE),
-	    ":",round(x$K.variants$pred4[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)],0),
+	cat("   with Source Examinee for Number-Incorrect Subgroup",ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE),
+	    ":",round(x$K.variants$pred4[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)],0),
 	"(rounded to the nearest integer)","\n")
 	} else 
-		if(x$K.variants$pred4[(ncol(x$data)-rowSums(x$data[x$suspected.pair[1],],na.rm=TRUE)+1)]>
-	         ncol(x$data)
+		if(x$K.variants$pred4[(ncol(x$data[,x$item.loc])-rowSums(x$data[,x$item.loc][x$single.pair2[1],],na.rm=TRUE)+1)]>
+	         ncol(x$data[,x$item.loc])
                ){   
                   cat("   Predicted average number of identical response is set to",
-                  ncol(x$data),"\n")
+                  ncol(x$data[,x$item.loc]),"\n")
                  cat("   ,the maximum possible number of matches, for S2 index.","\n")
 		 }
 	cat("","\n")
 	cat("S2 index p value:",round(x$K.variants$S2.index,3),"\n")
 } else cat("")
 
+	cat("***************************","    M4 Index         ","*******************************","\n")
+	cat("","\n")
+	cat("The detailed results for the M4 index is not printed here due to a large size of matrix ","\n")
+	cat("for the exact probability distribution. Please type 'x$M4.index$exact.prob.dist' where 'x' ","\n")
+	cat("should be replaced with the object name you assign for the results of the function.","\n")
+	cat("","\n")
+	cat("M4 index p value:",round(x$M4.index$p.value,3),"\n")
 }
 
 
